SLiCAP Development Team — SLiCAP 3.5.1 documentation

# SLiCAP Development Team

If you would like to contribute to SLiCAP please Mail us!

1. Anton J.M. Montagne

   Since 2009, Anton developed the concept and several implementations of SLiCAP.

   Anton is the main author of the project.

2. Charles White

   Developed the Frequency Constants Module and the State Space Module.

   Charles is the current maintainer of the SLiCAP_python git repository

3. Aitor del Rivero Cortazar

   Developed the Cadence2traces function

4. Jokin Segundo Babarro

   Advises on Python methods and techniques